@@ -1,13 +1,3 @@
-#[inline]
-pub fn default_env_vars() -> Vec<String> {
-    vec![]
-}
-
-#[inline]
-pub fn default_padding_x() -> f32 {
-    0.
-}
-
 #[inline]
 pub fn default_bool_true() -> bool {
     true
@@ -127,10 +117,16 @@ cursor = '▇'
 
 # Blinking Cursor
 #
-# Default is false
+# Default is true
 #
 blinking-cursor = false
 
+# Hide the cursor while typing
+#
+# Default is `false`
+#
+# hide-cursor-when-typing = false
+
 # Ignore theme selection foreground color
 #
 # Default is false
@@ -156,27 +152,32 @@ blinking-cursor = false
 
 # Option as Alt
 #
-# This config only works on MacOs.
+# This config only works on MacOS.
 # Possible choices: 'both', 'left' and 'right'.
 #
 # Example:
 # option-as-alt = 'left'
 
+# Line height
+#
+# This option will apply an modifier to line-height
+# Default is `1.0`
+#
+# Example:
+# line-height = 1.2
+
 # Startup directory
 #
 # Directory the shell is started in. If this is unset the working
 # directory of the parent process will be used.
 #
-# This configuration only has effect if use-fork is disabled
+# This configuration only has effect if use-fork is disabled.
 #
 # Example:
 # working-dir = "/Users/raphael/Documents/"
 
 # Environment variables
 #
-# The example below sets fish as the default SHELL using env vars
-# please do not copy this if you do not need
-#
 # Example:
 # env-vars = []
 
@@ -189,6 +190,11 @@ blinking-cursor = false
 # Example:
 # use-fork = false
 
+# Confirm before exiting Rio
+# Default is `true`
+#
+# confirm-before-quit = false
+
 # Window configuration
 #
 # • width - define the intial window width.
@@ -202,9 +208,7 @@ blinking-cursor = false
 #     - "Maximized" window is created with maximized
 #     - "Fullscreen" window is created with fullscreen
 #
-# • background-opacity - Set background opacity
-#
-# • foreground-opacity - Set foreground opacity
+# • opacity - Set window opacity
 #
 # • blur - Set blur on the window background. Changing this config requires restarting Rio to take effect.
 #
@@ -215,8 +219,7 @@ blinking-cursor = false
 # width = 600
 # height = 400
 # mode = "Windowed"
-# foreground-opacity = 1.0
-# background-opacity = 1.0
+# opacity = 1.0
 # blur = false
 # decorations = "Enabled"
 
@@ -231,16 +234,22 @@ blinking-cursor = false
 #   - GL: Supported on Linux/Android, and Windows and macOS/iOS via ANGLE
 #   - Vulkan: Supported on Windows, Linux/Android
 #   - DX12: Supported on Windows 10
-#   - DX11: Supported on Windows 7+
 #   - Metal: Supported on macOS/iOS
 #
-# • disable-renderer-when-unfocused: This property disable renderer processes while Rio is unfocused.
+# • disable-unfocused-render: This property disable renderer processes while Rio is unfocused.
 #
+# • level: Configure renderer level
+#   - Available options: 0 and 1.
+#       Higher the level more rendering features and computations
+#       will be done like enable font ligatures or emoji support.
+#       For more information please check the docs.
+# 
 # Example:
 # [renderer]
 # performance = "High"
 # backend = "Automatic"
-# disable-renderer-when-unfocused = false
+# disable-unfocused-render = false
+# level = 1
 
 # Keyboard
 #
@@ -313,7 +322,7 @@ blinking-cursor = false
 # Navigation
 #
 # "mode" - Define navigation mode
-#   • NativeTab (MacOs only)
+#   • NativeTab (MacOS only)
 #   • CollapsedTab
 #   • BottomTab
 #   • TopTab
@@ -321,7 +330,7 @@ blinking-cursor = false
 #   • Plain
 #
 # "clickable" - Enable click on tabs to switch.
-# "use-current-path" - Use same path whenever a new tab is created.
+# "use-current-path" - Use same path whenever a new tab is created (Note: requires `use-fork` to be set to false).
 # "color-automation" - Set a specific color for the tab whenever a specific program is running, or in a specific directory.
 #
 # Example:
