@@ -98,11 +98,11 @@ pub struct Config {
     pub fonts: SugarloafFonts,
     #[serde(default = "default_editor")]
     pub editor: String,
-    #[serde(rename = "padding-x", default = "default_padding_x")]
+    #[serde(rename = "padding-x", default = "f32::default")]
     pub padding_x: f32,
     #[serde(default = "default_cursor")]
     pub cursor: char,
-    #[serde(default = "default_env_vars", rename = "env-vars")]
+    #[serde(default = "Vec::default", rename = "env-vars")]
     pub env_vars: Vec<String>,
     #[serde(default = "default_option_as_alt", rename = "option-as-alt")]
     pub option_as_alt: String,
@@ -192,16 +192,18 @@ impl Config {
 
                         if let Ok(light_loaded_theme) = Config::load_theme(&path) {
                             adaptive_colors.light = Some(light_loaded_theme.colors);
+                            println!("carregou");
                         } else {
-                            warn!("failed to load light theme: {}", light_theme);
+                            println!("failed to load light theme: {}", light_theme);
                         }
 
                         let dark_theme = &adaptive_theme.dark;
                         let path = tmp.join(dark_theme).with_extension("toml");
                         if let Ok(dark_loaded_theme) = Config::load_theme(&path) {
                             adaptive_colors.dark = Some(dark_loaded_theme.colors);
+                            println!("carregou");
                         } else {
-                            warn!("failed to load dark theme: {}", dark_theme);
+                            println!("failed to load dark theme: {}", dark_theme);
                         }
 
                         if adaptive_colors.light.is_some()
@@ -352,12 +354,12 @@ impl Default for Config {
             scroll: Scroll::default(),
             keyboard: Keyboard::default(),
             developer: Developer::default(),
-            env_vars: default_env_vars(),
+            env_vars: vec![],
             fonts: SugarloafFonts::default(),
             line_height: default_line_height(),
             navigation: Navigation::default(),
             option_as_alt: default_option_as_alt(),
-            padding_x: default_padding_x(),
+            padding_x: f32::default(),
             renderer: Renderer::default(),
             shell: default_shell(),
             theme: String::default(),
@@ -447,7 +449,8 @@ mod tests {
             result.renderer.performance,
             renderer::Performance::default()
         );
-        assert_eq!(result.env_vars, default_env_vars());
+        let env_vars: Vec<String> = vec![];
+        assert_eq!(result.env_vars, env_vars);
         assert_eq!(result.cursor, default_cursor());
         assert_eq!(result.theme, String::default());
         assert_eq!(result.cursor, default_cursor());
@@ -646,8 +649,7 @@ mod tests {
             performance = "Low"
 
             [window]
-            background-opacity = 0.5
-            foreground-opacity = 1.0
+            opacity = 0.5
             [window.background-image]
             path = "my-image-path.png"
 
@@ -660,13 +662,12 @@ mod tests {
         assert_eq!(result.fonts.size, 14.0);
         assert_eq!(result.line_height, 2.0);
         assert_eq!(result.padding_x, 0.0);
-        assert_eq!(result.window.background_opacity, 0.5);
-        assert_eq!(result.window.foreground_opacity, 1.0);
+        assert_eq!(result.window.opacity, 0.5);
         assert_eq!(
             result.window.background_image,
-            Some(sugarloaf::core::ImageProperties {
+            Some(sugarloaf::ImageProperties {
                 path: String::from("my-image-path.png"),
-                ..sugarloaf::core::ImageProperties::default()
+                ..sugarloaf::ImageProperties::default()
             })
         );
         // Colors
