@@ -2,8 +2,6 @@ mod atlas;
 mod raster;
 pub mod types;
 
-// #[cfg(feature = "svg")]
-// mod vector;
 use crate::context::Context;
 use atlas::Atlas;
 
@@ -21,8 +19,6 @@ use crate::components::core::image;
 #[derive(Debug)]
 pub struct LayerBrush {
     raster_cache: RefCell<raster::Cache>,
-    // #[cfg(feature = "svg")]
-    // vector_cache: RefCell<vector::Cache>,
     pipeline: wgpu::RenderPipeline,
     vertices: wgpu::Buffer,
     indices: wgpu::Buffer,
@@ -189,7 +185,7 @@ impl LayerBrush {
         });
 
         let shader = device.create_shader_module(wgpu::ShaderModuleDescriptor {
-            label: Some("iced_wgpu image shader"),
+            label: Some("layer image shader"),
             source: wgpu::ShaderSource::Wgsl(std::borrow::Cow::Borrowed(include_str!(
                 "image.wgsl"
             ))),
@@ -199,6 +195,7 @@ impl LayerBrush {
             label: Some("image pipeline"),
             layout: Some(&layout),
             vertex: wgpu::VertexState {
+                compilation_options: wgpu::PipelineCompilationOptions::default(),
                 module: &shader,
                 entry_point: "vs_main",
                 buffers: &[
@@ -225,6 +222,7 @@ impl LayerBrush {
                 ],
             },
             fragment: Some(wgpu::FragmentState {
+                compilation_options: wgpu::PipelineCompilationOptions::default(),
                 module: &shader,
                 entry_point: "fs_main",
                 targets: &[Some(wgpu::ColorTargetState {
@@ -283,9 +281,6 @@ impl LayerBrush {
 
         LayerBrush {
             raster_cache: RefCell::new(raster::Cache::default()),
-
-            // #[cfg(feature = "svg")]
-            // vector_cache: RefCell::new(vector::Cache::default()),
             pipeline,
             vertices,
             indices,
@@ -295,7 +290,6 @@ impl LayerBrush {
             texture_atlas,
             texture_layout,
             constant_layout,
-
             layers: Vec::new(),
             prepare_layer: 0,
         }
@@ -308,14 +302,6 @@ impl LayerBrush {
         memory.dimensions()
     }
 
-    // #[cfg(feature = "svg")]
-    // pub fn viewport_dimensions(&self, handle: &svg::Handle) -> Size<u32> {
-    //     let mut cache = self.vector_cache.borrow_mut();
-    //     let svg = cache.load(handle);
-
-    //     svg.viewport_dimensions()
-    // }
-
     pub fn prepare(
         &mut self,
         encoder: &mut wgpu::CommandEncoder,
@@ -324,16 +310,13 @@ impl LayerBrush {
         // transformation: [f32; 16],
         // _scale: f32,
     ) {
-        let transformation: [f32; 16] = orthographic_projection(300, 300);
+        let transformation: [f32; 16] = orthographic_projection(300.0, 300.0);
         let device = &ctx.device;
         let queue = &ctx.queue;
 
         let instances: &mut Vec<Instance> = &mut Vec::new();
         let mut raster_cache = self.raster_cache.borrow_mut();
 
-        // #[cfg(feature = "svg")]
-        // let mut vector_cache = self.vector_cache.borrow_mut();
-
         for image in images {
             match &image {
                 types::Image::Raster { handle, bounds } => {
@@ -350,36 +333,7 @@ impl LayerBrush {
                             instances,
                         );
                     }
-                } // #[cfg(not(feature = "image"))]
-                  // types::Image::Raster { .. } => {}
-
-                  // #[cfg(feature = "svg")]
-                  // types::Image::Vector {
-                  //     handle,
-                  //     color,
-                  //     bounds,
-                  // } => {
-                  //     let size = [bounds.width, bounds.height];
-
-                  //     if let Some(atlas_entry) = vector_cache.upload(
-                  //         device,
-                  //         encoder,
-                  //         handle,
-                  //         *color,
-                  //         size,
-                  //         _scale,
-                  //         &mut self.texture_atlas,
-                  //     ) {
-                  //         add_instances(
-                  //             [bounds.x, bounds.y],
-                  //             size,
-                  //             atlas_entry,
-                  //             instances,
-                  //         );
-                  //     }
-                  // }
-                  // #[cfg(not(feature = "svg"))]
-                  // types::Image::Vector { .. } => {}
+                }
             }
         }
 
@@ -425,16 +379,13 @@ impl LayerBrush {
         // transformation: [f32; 16],
         // _scale: f32,
     ) {
-        let transformation: [f32; 16] = orthographic_projection(300, 300);
+        let transformation: [f32; 16] = orthographic_projection(300.0, 300.0);
         let device = &ctx.device;
         let queue = &ctx.queue;
 
         let instances: &mut Vec<Instance> = &mut Vec::new();
         let mut raster_cache = self.raster_cache.borrow_mut();
 
-        // #[cfg(feature = "svg")]
-        // let mut vector_cache = self.vector_cache.borrow_mut();
-
         for image in images {
             match &image {
                 types::Image::Raster { handle, bounds } => {
@@ -451,36 +402,7 @@ impl LayerBrush {
                             instances,
                         );
                     }
-                } // #[cfg(not(feature = "image"))]
-                  // types::Image::Raster { .. } => {}
-
-                  // #[cfg(feature = "svg")]
-                  // types::Image::Vector {
-                  //     handle,
-                  //     color,
-                  //     bounds,
-                  // } => {
-                  //     let size = [bounds.width, bounds.height];
-
-                  //     if let Some(atlas_entry) = vector_cache.upload(
-                  //         device,
-                  //         encoder,
-                  //         handle,
-                  //         *color,
-                  //         size,
-                  //         _scale,
-                  //         &mut self.texture_atlas,
-                  //     ) {
-                  //         add_instances(
-                  //             [bounds.x, bounds.y],
-                  //             size,
-                  //             atlas_entry,
-                  //             instances,
-                  //         );
-                  //     }
-                  // }
-                  // #[cfg(not(feature = "svg"))]
-                  // types::Image::Vector { .. } => {}
+                }
             }
         }
 
@@ -518,16 +440,24 @@ impl LayerBrush {
         self.prepare_layer += 1;
     }
 
+    #[inline]
     pub fn render<'a>(
         &'a self,
         layer: usize,
-        bounds: Rectangle<u32>,
         render_pass: &mut wgpu::RenderPass<'a>,
+        rect_bounds: Option<Rectangle<u32>>,
     ) {
         if let Some(layer) = self.layers.get(layer) {
             render_pass.set_pipeline(&self.pipeline);
 
-            render_pass.set_scissor_rect(bounds.x, bounds.y, bounds.width, bounds.height);
+            if let Some(bounds) = rect_bounds {
+                render_pass.set_scissor_rect(
+                    bounds.x,
+                    bounds.y,
+                    bounds.width,
+                    bounds.height,
+                );
+            }
 
             render_pass.set_bind_group(1, &self.texture, &[]);
             render_pass
@@ -580,16 +510,13 @@ impl LayerBrush {
 
             layer.render(&mut render_pass);
 
-            // drop(render_pass);
+            drop(render_pass);
         }
     }
 
     pub fn end_frame(&mut self) {
         self.raster_cache.borrow_mut().trim(&mut self.texture_atlas);
 
-        // #[cfg(feature = "svg")]
-        // self.vector_cache.borrow_mut().trim(&mut self.texture_atlas);
-
         self.prepare_layer = 0;
     }
 }
